summaryrefslogtreecommitdiff
path: root/sleekxmpp/basexmpp.py
diff options
context:
space:
mode:
authorLance Stout <lancestout@gmail.com>2011-01-05 16:53:33 -0500
committerLance Stout <lancestout@gmail.com>2011-01-05 16:53:33 -0500
commitc156a4f723073e1e6394803b5bb1613227947266 (patch)
tree1f7aaf623e4cdca994969282fb7468fa85712d37 /sleekxmpp/basexmpp.py
parent3657bf66363844bf7351ea84279eeb74b0449d5f (diff)
parent8b29431cdeff5647208e3eab108bba9e9c8318fc (diff)
downloadslixmpp-c156a4f723073e1e6394803b5bb1613227947266.tar.gz
slixmpp-c156a4f723073e1e6394803b5bb1613227947266.tar.bz2
slixmpp-c156a4f723073e1e6394803b5bb1613227947266.tar.xz
slixmpp-c156a4f723073e1e6394803b5bb1613227947266.zip
Merge branch 'develop' into roster
Diffstat (limited to 'sleekxmpp/basexmpp.py')
-rw-r--r--sleekxmpp/basexmpp.py16
1 files changed, 8 insertions, 8 deletions
diff --git a/sleekxmpp/basexmpp.py b/sleekxmpp/basexmpp.py
index bc02e5f6..b1d04639 100644
--- a/sleekxmpp/basexmpp.py
+++ b/sleekxmpp/basexmpp.py
@@ -271,24 +271,24 @@ class BaseXMPP(XMLStream):
"""Create a Presence stanza associated with this stream."""
return Presence(self, *args, **kwargs)
- def make_iq(self, id=0, ifrom=None, ito=None, type=None, query=None):
+ def make_iq(self, id=0, ifrom=None, ito=None, itype=None, iquery=None):
"""
Create a new Iq stanza with a given Id and from JID.
Arguments:
- id -- An ideally unique ID value for this stanza thread.
- Defaults to 0.
- ifrom -- The from JID to use for this stanza.
- ito -- The destination JID for this stanza.
- type -- The Iq's type, one of: get, set, result, or error.
- query -- Optional namespace for adding a query element.
+ id -- An ideally unique ID value for this stanza thread.
+ Defaults to 0.
+ ifrom -- The from JID to use for this stanza.
+ ito -- The destination JID for this stanza.
+ itype -- The Iq's type, one of: get, set, result, or error.
+ iquery -- Optional namespace for adding a query element.
"""
iq = self.Iq()
iq['id'] = str(id)
iq['to'] = ito
iq['from'] = ifrom
iq['type'] = itype
- iq['query'] = query
+ iq['query'] = iquery
return iq
def make_iq_get(self, queryxmlns=None, ito=None, ifrom=None, iq=None):